import { TypeRevivers, TypeReviverMap, PresetTypeReviverMap } from "type-reviver";
import { Reviver, JSONStringifyOptions } from "./public";
export interface CustomJSONStringify extends PresetTypeReviverMap<Reviver> {
    <Revr extends Reviver>(value: any, typeRevivers?: TypeRevivers<Revr> | null, options?: JSONStringifyOptions): string;
}
/**
 * 默认 Revier 的 TypeName
 */
export declare const typeNameOfDefaultRevier = "default";
export declare function createCustomJSONStringify(presetTypeReviverMap?: TypeReviverMap<Reviver>): CustomJSONStringify;
export interface CustomJSONParse extends PresetTypeReviverMap<Reviver> {
    <Revr extends Reviver>(text: string, typeRevivers?: TypeRevivers<Revr> | null, options?: JSONParseOptions): any;
}
export declare enum LostRevier {
    original = "original",
    parse = "parse",
    ignore = "ignore"
}
export interface JSONParseOptions {
    mark?: string | null;
    lostRevier?: LostRevier;
}
export declare function createCustomJSONParse(presetTypeReviverMap?: TypeReviverMap<Reviver>): CustomJSONParse;
export interface CustomJSON {
    stringify: CustomJSONStringify;
    parse: CustomJSONParse;
}
export declare function createCustomJSON(presetTypeReviverMap?: TypeReviverMap<Reviver>): CustomJSON;
/**
 * 自定义JSON序列化；可根据数据类型来自定义序列化方案； 给合  customJSONParse  可实现对任意类型的数据 进行序列化 并完整（无信息丢失）还原；
 * @param value: any   被序列化的对象
 * @param typeRevivers?:TypeRevivers|null    定义 类型 与 其对类的 自定义序列化函数；
 * @param options:JSONStringifyOptions    选项
 */
export declare const customJSONStringify: CustomJSONStringify;
/**
 * 自定义JSON解析；可根据类型自定义解析逻辑；
 * @param text
 * @param typeRevivers
 * @param options
 */
export declare const customJSONParse: CustomJSONParse;
